@@ -2,9 +2,13 @@
 from captcha.conf import settings
 from captcha.fields import CaptchaField, CaptchaTextInput
 from captcha.models import CaptchaStore
+import django
 from django.core import management
 from django.core.exceptions import ImproperlyConfigured
-from django.core.urlresolvers import reverse
+if django.VERSION < (1, 10):  # NOQA
+    from django.core.urlresolvers import reverse  # NOQA
+else:  # NOQA
+    from django.urls import reverse  # NOQA
 from django.test import TestCase, override_settings
 from django.utils.translation import ugettext_lazy
 from django.utils import timezone
@@ -20,11 +24,7 @@ except ImportError:
     from io import BytesIO as StringIO
 
 from six import u, text_type
-
-try:
-    from PIL import Image
-except ImportError:
-    import Image  # NOQA
+from PIL import Image
 
 
 @override_settings(ROOT_URLCONF='captcha.tests.urls')
@@ -73,9 +73,9 @@ class CaptchaCase(TestCase):
         for key in (self.stores.get('math_store').hashkey, self.stores.get('math_store').hashkey, self.default_store.hashkey):
             response = self.client.get(reverse('captcha-audio', kwargs=dict(key=key)))
             self.assertEqual(response.status_code, 200)
-            self.assertTrue(len(response.content) > 1024)
+            self.assertTrue(response.ranged_file.size > 1024)
             self.assertTrue(response.has_header('content-type'))
-            self.assertEqual(response._headers.get('content-type'), ('Content-Type', 'audio/x-wav'))
+            self.assertEqual(response._headers.get('content-type'), ('Content-Type', 'audio/wav'))
 
     def test_form_submit(self):
         r = self.client.get(reverse('captcha-test'))
@@ -223,6 +223,7 @@ class CaptchaCase(TestCase):
         try:
             new_data = json.loads(six.text_type(r.content, encoding='ascii'))
             self.assertTrue('image_url' in new_data)
+            self.assertTrue('audio_url' in new_data)
         except:
             self.fail()
 
