@@ -1,6 +1,6 @@
 from django.conf.urls import url, include
 from .views import (
-    test, test_model_form, test_custom_error_message, test_per_form_format, test_non_required, test_id_prefix
+    test, test_model_form, test_custom_error_message, test_per_form_format, test_non_required, test_id_prefix, test_custom_generator
 )
 
 urlpatterns = [
@@ -8,6 +8,7 @@ urlpatterns = [
     url(r'test-modelform/$', test_model_form, name='captcha-test-model-form'),
     url(r'test2/$', test_custom_error_message, name='captcha-test-custom-error-message'),
     url(r'test3/$', test_per_form_format, name='test_per_form_format'),
+    url(r'custom-generator/$', test_custom_generator, name='test_custom_generator'),
     url(r'test-non-required/$', test_non_required, name='captcha-test-non-required'),
     url(r'test-id-prefix/$', test_id_prefix, name='captcha-test-id-prefix'),
     url(r'', include('captcha.urls')),
