@@ -1,10 +1,10 @@
 from captcha.conf import settings
-from captcha.helpers import captcha_image_url
+from captcha.helpers import captcha_image_url, captcha_audio_url
 from captcha.models import CaptchaStore
 from django.http import HttpResponse, Http404
 from django.core.exceptions import ImproperlyConfigured
+from ranged_response import RangedFileResponse
 import random
-import re
 import tempfile
 import os
 import subprocess
@@ -15,21 +15,15 @@ try:
 except ImportError:
     from io import BytesIO as StringIO
 
-try:
-    from PIL import Image, ImageDraw, ImageFont
-except ImportError:
-    import Image
-    import ImageDraw
-    import ImageFont
+from PIL import Image, ImageDraw, ImageFont
 
 try:
     import json
 except ImportError:
     from django.utils import simplejson as json
 
-NON_DIGITS_RX = re.compile('[^\d]')
 # Distance of the drawn text from the top of the captcha image
-from_top = 4
+DISTNACE_FROM_TOP = 4
 
 
 def getsize(font, text):
@@ -75,11 +69,6 @@ def captcha_image(request, key, scale=1):
         size = (size[0] * 2, int(size[1] * 1.4))
 
     image = makeimg(size)
-
-    try:
-        PIL_VERSION = int(NON_DIGITS_RX.sub('', Image.VERSION))
-    except:
-        PIL_VERSION = 116
     xpos = 2
 
     charlist = []
@@ -94,14 +83,11 @@ def captcha_image(request, key, scale=1):
         chardraw = ImageDraw.Draw(charimage)
         chardraw.text((0, 0), ' %s ' % char, font=font, fill='#ffffff')
         if settings.CAPTCHA_LETTER_ROTATION:
-            if PIL_VERSION >= 116:
-                charimage = charimage.rotate(random.randrange(*settings.CAPTCHA_LETTER_ROTATION), expand=0, resample=Image.BICUBIC)
-            else:
-                charimage = charimage.rotate(random.randrange(*settings.CAPTCHA_LETTER_ROTATION), resample=Image.BICUBIC)
+            charimage = charimage.rotate(random.randrange(*settings.CAPTCHA_LETTER_ROTATION), expand=0, resample=Image.BICUBIC)
         charimage = charimage.crop(charimage.getbbox())
         maskimage = Image.new('L', size)
 
-        maskimage.paste(charimage, (xpos, from_top, xpos + charimage.size[0], from_top + charimage.size[1]))
+        maskimage.paste(charimage, (xpos, DISTNACE_FROM_TOP, xpos + charimage.size[0], DISTNACE_FROM_TOP + charimage.size[1]))
         size = maskimage.size
         image = Image.composite(fgimage, image, maskimage)
         xpos = xpos + 2 + charimage.size[0]
@@ -109,7 +95,7 @@ def captcha_image(request, key, scale=1):
     if settings.CAPTCHA_IMAGE_SIZE:
         # centering captcha on the image
         tmpimg = makeimg(size)
-        tmpimg.paste(image, (int((size[0] - xpos) / 2), int((size[1] - charimage.size[1]) / 2 - from_top)))
+        tmpimg.paste(image, (int((size[0] - xpos) / 2), int((size[1] - charimage.size[1]) / 2 - DISTNACE_FROM_TOP)))
         image = tmpimg.crop((0, 0, size[0], size[1]))
     else:
         image = image.crop((0, 0, xpos + 1, size[1]))
@@ -146,13 +132,20 @@ def captcha_audio(request, key):
             text = ', '.join(list(text))
         path = str(os.path.join(tempfile.gettempdir(), '%s.wav' % key))
         subprocess.call([settings.CAPTCHA_FLITE_PATH, "-t", text, "-o", path])
+
+        # Add arbitrary noise if sox is installed
+        if settings.CAPTCHA_SOX_PATH:
+            arbnoisepath = str(os.path.join(tempfile.gettempdir(), '%s_arbitrary.wav') % key)
+            mergedpath = str(os.path.join(tempfile.gettempdir(), '%s_merged.wav') % key)
+            subprocess.call([settings.CAPTCHA_SOX_PATH, '-r', '8000', '-n', arbnoisepath, 'synth', '2', 'brownnoise', 'gain', '-15'])
+            subprocess.call([settings.CAPTCHA_SOX_PATH, '-m', arbnoisepath, path, '-t', 'wavpcm', '-b', '16', mergedpath])
+            os.remove(arbnoisepath)
+            os.remove(path)
+            os.rename(mergedpath, path)
+
         if os.path.isfile(path):
-            response = HttpResponse()
-            f = open(path, 'rb')
-            response['Content-Type'] = 'audio/x-wav'
-            response.write(f.read())
-            f.close()
-            os.unlink(path)
+            response = RangedFileResponse(request, open(path, 'rb'), content_type='audio/wav')
+            response['Content-Disposition'] = 'attachment; filename="{}.wav"'.format(key)
             return response
     raise Http404
 
@@ -166,5 +159,6 @@ def captcha_refresh(request):
     to_json_response = {
         'key': new_key,
         'image_url': captcha_image_url(new_key),
+        'audio_url': captcha_audio_url(new_key) if settings.CAPTCHA_FLITE_PATH else None
     }
     return HttpResponse(json.dumps(to_json_response), content_type='application/json')
